==> lmtpd-0.9.19.tar.gz: lmtpd-0.9.19/re/re-fnmatch.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

static char const rcsid[] = 
"$Id: re-fnmatch.c,v 1.9 2003/11/27 01:13:31 lwa Exp $";

#include "config.h"

#include <sys/types.h>

#include <stdlib.h>
#include <string.h>
#include <fnmatch.h>
#include <ctype.h>
#include "re.h"

static void re_close(RE *re) {
  if (re->code)
    free(re->code);
  re->code = NULL;
}

static int re_exec_icase(RE *re, char *string) {
  int option;
  int ret;
#if !FNM_CASEFOLD
  option = 0;
  string = strdup(string);
  if (string) {
    char *s = string;
    while(*s) {
      *s = tolower(*s);
      s++;
    }
  } else {
    return -1;
  }
#else
  option = FNM_CASEFOLD;
#endif
  ret = fnmatch(re->code, string, option);
#if !FNM_CASEFOLD
  free(string);
#endif
  return ret!=0;
}

static int re_exec(RE *re, char *string) {
  int ret = fnmatch(re->code, string, 0);
  return ret!=0;
}

static int re_compile(RE *re, char *pattern, int icase) {
  re->code = strdup(pattern);
  if (re->code == NULL) {
    re->err = RE_ERR_MEMORY;
    re->errstr = "memory";
  } else {
    re->err = 0;
  }

  if (icase)
    re->exec = re_exec_icase;
  else
    re->exec = re_exec;
#if !FNM_CASEFOLD
  pattern = re->code;
  while(*pattern) {
    *pattern = tolower(*pattern);
    pattern++;
  }
#endif
  
  return re->err;
}



RE re_fnmatch = {
  re_compile,
  re_exec,
  re_close,
  0,
  0,
};

==> lmtpd-0.10.7.tar.gz: lmtpd-0.10.7/re/re-fnmatch.c <==
/*
   Copyright 2000, 2001, 2002, 2003 Laurent Wacrenier

   This file is part of PLL lmtpd.

   PLL lmtpd is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   PLL lmtpd is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with PLL lmtpd; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#include "config.h"

static char const rcsid[] UNUSED = 
"$Id: re-fnmatch.c,v 1.10 2004/10/26 09:59:21 lwa Exp $";



#include <sys/types.h>

#include <stdlib.h>
#include <string.h>
#include <fnmatch.h>
#include <ctype.h>
#include "re.h"

static void re_close(RE *re) {
  if (re->code)
    free(re->code);
  re->code = NULL;
}

static int re_exec_icase(RE *re, char *string) {
  int option;
  int ret;
#if !FNM_CASEFOLD
  option = 0;
  string = strdup(string);
  if (string) {
    char *s = string;
    while(*s) {
      *s = tolower(*s);
      s++;
    }
  } else {
    return -1;
  }
#else
  option = FNM_CASEFOLD;
#endif
  ret = fnmatch(re->code, string, option);
#if !FNM_CASEFOLD
  free(string);
#endif
  return ret!=0;
}

static int re_exec(RE *re, char *string) {
  int ret = fnmatch(re->code, string, 0);
  return ret!=0;
}

static int re_compile(RE *re, char *pattern, int icase) {
  re->code = strdup(pattern);
  if (re->code == NULL) {
    re->err = RE_ERR_MEMORY;
    re->errstr = "memory";
  } else {
    re->err = 0;
  }

  if (icase)
    re->exec = re_exec_icase;
  else
    re->exec = re_exec;
#if !FNM_CASEFOLD
  pattern = re->code;
  while(*pattern) {
    *pattern = tolower(*pattern);
    pattern++;
  }
#endif
  
  return re->err;
}



RE re_fnmatch = {
  re_compile,
  re_exec,
  re_close,
  0,
  0,
};
